@@ -14,8 +14,7 @@
 # ============================================================================
 """An implementation of a dm_env environment using dm_env_rpc."""
 
-import collections
-from typing import Any, Iterable, Mapping, Optional, Sequence, Tuple
+from typing import Any, Iterable, Mapping, NamedTuple, Optional, Sequence
 import dm_env
 import immutabledict
 
@@ -78,10 +77,14 @@ class DmEnvAdaptor(dm_env.Environment):
 
     if requested_observations is None:
       requested_observations = self._observation_specs.names()
-    requested_observations = set(requested_observations)
+      self._is_reward_requested = False
+      self._is_discount_requested = False
+    else:
+      self._is_reward_requested = DEFAULT_REWARD_KEY in requested_observations
+      self._is_discount_requested = (
+          DEFAULT_DISCOUNT_KEY in requested_observations)
 
-    self._is_reward_requested = DEFAULT_REWARD_KEY in requested_observations
-    self._is_discount_requested = DEFAULT_DISCOUNT_KEY in requested_observations
+    requested_observations = set(requested_observations)
 
     self._default_reward_spec = None
     self._default_discount_spec = None
@@ -285,7 +288,8 @@ def join_world(
     world_name: str,
     join_world_settings: Mapping[str, Any],
     requested_observations: Optional[Iterable[str]] = None,
-    extensions: Optional[Mapping[str, Any]] = immutabledict.immutabledict()
+    extensions: Optional[Mapping[str, Any]] = immutabledict.immutabledict(),
+    nested_tensors: bool = True
 ) -> DmEnvAdaptor:
   """Helper function to join a world with the provided settings.
 
@@ -298,6 +302,7 @@ def join_world(
     requested_observations: Optional set of requested observations.
     extensions: Optional mapping of extension instances to DmEnvAdaptor
       attributes.
+    nested_tensors: Boolean to determine whether to flatten/unflatten tensors.
 
   Returns:
     Instance of DmEnvAdaptor.
@@ -314,19 +319,25 @@ def join_world(
 
   try:
     return DmEnvAdaptor(
-        connection, specs, requested_observations, extensions=extensions)
+        connection, specs, requested_observations, nested_tensors, extensions)
   except ValueError:
     connection.send(dm_env_rpc_pb2.LeaveWorldRequest())
     raise
 
 
+class DmEnvAndWorldName(NamedTuple):
+  """Environment and world_name created when calling create_and_join_world."""
+  env: DmEnvAdaptor
+  world_name: str
+
+
 def create_and_join_world(
     connection: dm_env_rpc_connection.Connection,
     create_world_settings: Mapping[str, Any],
     join_world_settings: Mapping[str, Any],
     requested_observations: Optional[Iterable[str]] = None,
-    extensions: Optional[Mapping[str, Any]] = immutabledict.immutabledict()
-) -> Tuple[DmEnvAdaptor, str]:
+    extensions: Optional[Mapping[str, Any]] = immutabledict.immutabledict(),
+    nested_tensors: bool = True) -> DmEnvAndWorldName:
   """Helper function to create and join a world with the provided settings.
 
   Args:
@@ -339,17 +350,17 @@ def create_and_join_world(
     requested_observations: Optional set of requested observations.
     extensions: Optional mapping of extension instances to DmEnvAdaptor
       attributes.
+    nested_tensors: Boolean to determine whether to flatten/unflatten tensors.
 
   Returns:
     Tuple of DmEnvAdaptor and the created world name.
   """
   world_name = create_world(connection, create_world_settings)
   try:
-    return_type = collections.namedtuple('DmEnvAndWorldName',
-                                         ['env', 'world_name'])
-    return return_type(
+    return DmEnvAndWorldName(
         join_world(connection, world_name, join_world_settings,
-                   requested_observations, extensions), world_name)
+                   requested_observations, extensions, nested_tensors),
+        world_name)
   except (error.DmEnvRpcError, ValueError):
     connection.send(dm_env_rpc_pb2.DestroyWorldRequest(world_name=world_name))
     raise
