@@ -340,6 +340,23 @@ class ReservedKeywordTests(absltest.TestCase):
 
     self.assertEqual('goodbye', timestep.discount)
 
+  def test_observations_empty(self):
+    self.assertEmpty(self._env.observation_spec())
+
+  def test_explicitly_requesting_reward_and_discount(self):
+    env = dm_env_adaptor.DmEnvAdaptor(
+        self._connection,
+        _RESERVED_SPEC,
+        requested_observations=[
+            dm_env_adaptor.DEFAULT_REWARD_KEY,
+            dm_env_adaptor.DEFAULT_DISCOUNT_KEY
+        ])
+    expected_observation_spec = {
+        dm_env_adaptor.DEFAULT_REWARD_KEY: env.reward_spec(),
+        dm_env_adaptor.DEFAULT_DISCOUNT_KEY: env.discount_spec(),
+    }
+    self.assertEqual(env.observation_spec(), expected_observation_spec)
+
 
 class EnvironmentAutomaticallyRequestsReservedKeywords(absltest.TestCase):
 
@@ -562,7 +579,7 @@ class CreateJoinHelpers(absltest.TestCase):
         dm_env_rpc_pb2.CreateWorldResponse(world_name='Magrathea_02'),
         dm_env_rpc_pb2.JoinWorldResponse(specs=_SAMPLE_SPEC)
     ])
-    env, world_name = dm_env_adaptor.create_and_join_world(
+    env_and_world_name = dm_env_adaptor.create_and_join_world(
         connection,
         create_world_settings={'planet': tensor_utils.pack_tensor('Magrathea')},
         join_world_settings={
@@ -570,8 +587,8 @@ class CreateJoinHelpers(absltest.TestCase):
             'player': tensor_utils.pack_tensor('arthur'),
             'unpacked_setting': [1, 2, 3],
         })
-    self.assertIsNotNone(env)
-    self.assertEqual('Magrathea_02', world_name)
+    self.assertIsNotNone(env_and_world_name.env)
+    self.assertEqual('Magrathea_02', env_and_world_name.world_name)
 
     connection.send.assert_has_calls([
         mock.call(
@@ -614,6 +631,29 @@ class CreateJoinHelpers(absltest.TestCase):
         extensions={'extension': _ExampleExtension()})
     self.assertEqual('bar', env.extension.foo())
 
+  def test_create_join_world_with_unnested_tensors(self):
+    connection = mock.MagicMock()
+    connection.send = mock.MagicMock(side_effect=[
+        dm_env_rpc_pb2.CreateWorldResponse(world_name='Damogran_01'),
+        dm_env_rpc_pb2.JoinWorldResponse(specs=_SAMPLE_NESTED_SPECS)
+    ])
+    env, _ = dm_env_adaptor.create_and_join_world(
+        connection,
+        create_world_settings={},
+        join_world_settings={},
+        nested_tensors=False)
+    expected_actions = {
+        'foo.bar': specs.Array(shape=(), dtype=np.int32, name='foo.bar'),
+        'baz': specs.Array(shape=(), dtype=np.str_, name='baz'),
+    }
+    expected_observations = {
+        'foo.bar': specs.Array(shape=(), dtype=np.int32, name='foo.bar'),
+        'baz': specs.Array(shape=(), dtype=np.str_, name='baz'),
+    }
+
+    self.assertSameElements(expected_actions, env.action_spec())
+    self.assertSameElements(expected_observations, env.observation_spec())
+
   def test_create_join_world_with_invalid_extension(self):
     connection = mock.MagicMock()
     connection.send = mock.MagicMock(side_effect=[
