@@ -18,7 +18,7 @@ Note that the Tensor proto payload type is not supported, as it doesn't play
 well with NumPy.
 """
 import abc
-from typing import Optional, Sequence, Union
+from typing import Optional, Union
 import numpy as np
 
 from google.protobuf import any_pb2
@@ -143,7 +143,7 @@ _NAME_TO_NP_TYPE = {
 }
 
 _TYPE_TO_PACKER = {
-    packer.np_type: packer for packer in _PACKERS
+    np.dtype(packer.np_type): packer for packer in _PACKERS
 }
 
 _DM_ENV_RPC_DTYPE_TO_NUMPY_DTYPE = {
@@ -216,7 +216,7 @@ def get_packer(np_type: np.dtype) -> Packer:
   Raises:
     TypeError: If the provided NumPy type has no known packer.
   """
-  packer = _TYPE_TO_PACKER.get(np_type)
+  packer = _TYPE_TO_PACKER.get(np.dtype(np_type))
   if not packer:
     raise TypeError(f'Unknown NumPy type "{np_type}" has no known packer.')
   return packer
@@ -239,24 +239,18 @@ def reshape_array(array: np.ndarray, shape):
     return array[0]
 
 
-def unpack_proto(proto: TensorOrTensorSpecValue,
-                 shape: Optional[Sequence[int]]):
+def unpack_proto(proto: TensorOrTensorSpecValue) -> np.ndarray:
   """Converts a proto with payload oneof to a scalar or NumPy array.
 
   Args:
     proto: A dm_env_rpc proto with payload oneof.
-    shape: Optional dimensions of the payload data. If not set or empty, the
-      data is assumed to be a scalar type.
 
   Returns:
-    If `shape` is empty or None, returns a scalar (float, int, string, etc.)
-    of the correct type and value. Otherwise returns a NumPy array of the
-    payload with the correct type and shape.
+    Returns a NumPy array of the payload with the correct type.
   """
   np_type = get_tensor_type(proto)
   packer = get_packer(np_type)
-  array = packer.unpack(proto)
-  return reshape_array(array, shape)
+  return packer.unpack(proto)
 
 
 def unpack_tensor(tensor_proto: dm_env_rpc_pb2.Tensor):
@@ -271,10 +265,14 @@ def unpack_tensor(tensor_proto: dm_env_rpc_pb2.Tensor):
     `shape` attribute is empty, returns a scalar (float, int, string, etc.)
     of the correct type and value.
   """
-  return unpack_proto(tensor_proto, tensor_proto.shape)
+  array = unpack_proto(tensor_proto)
+  return reshape_array(array, tensor_proto.shape)
 
 
-def pack_tensor(value, dtype=None, try_compress=False) -> dm_env_rpc_pb2.Tensor:
+def pack_tensor(value,
+                dtype: Optional[Union[np.dtype,
+                                      'dm_env_rpc_pb2.DataType']] = None,
+                try_compress=False) -> dm_env_rpc_pb2.Tensor:
   """Encodes the given value as a tensor.
 
   Args:
@@ -299,7 +297,7 @@ def pack_tensor(value, dtype=None, try_compress=False) -> dm_env_rpc_pb2.Tensor:
   packed = dm_env_rpc_pb2.Tensor()
   value = np.asarray(value)
 
-  if value.dtype == np.object:
+  if value.dtype == object:
     # Because Numpy doesn't truly support variable-length string arrays, users
     # tend to use arrays of Numpy objects instead. Iff a user provides an array
     # of objects and a string dtype argument, automatically convert the value to
@@ -314,13 +312,15 @@ def pack_tensor(value, dtype=None, try_compress=False) -> dm_env_rpc_pb2.Tensor:
       value = np.array(value, dtype=np.str_)
 
   elif dtype is not None:
+    # NumPy defaults to np.float64 dtype when calling np.asarray() on an empty
+    # array. Allow unsafe casting in this particular case.
     value = value.astype(
         dtype=_DM_ENV_RPC_DTYPE_TO_NUMPY_DTYPE.get(dtype, dtype),
         copy=False,
-        casting='same_kind')
+        casting='same_kind' if value.size else 'unsafe')
 
   packed.shape[:] = value.shape
-  packer = _TYPE_TO_PACKER[value.dtype.type]
+  packer = get_packer(value.dtype.type)
   if (try_compress and np.all(value == next(value.flat))):
     # All elements are the same.  Pack in to a single value.
     packer.pack(packed, value.ravel()[0:1])
