@@ -83,6 +83,7 @@ class PackTensorTests(parameterized.TestCase):
       (25, np.int64, 'int64s'),
       (25, np.uint32, 'uint32s'),
       (25, np.uint64, 'uint64s'),
+      (2**64-1, np.uint64, 'uint64s'),
       (True, np.bool, 'bools'),
       (False, np.bool, 'bools'),
       ('foo', np.str, 'strings'),
@@ -124,6 +125,19 @@ class PackTensorTests(parameterized.TestCase):
     packed_array = getattr(tensor, expected_payload).array
     np.testing.assert_array_equal(array, packed_array)
 
+  @parameterized.parameters(
+      ([], None, 'doubles'),
+      ([], np.int64, 'int64s'),
+      ([1, 2, 3], None, 'int64s'),
+      ([1, 2, 3], np.int32, 'int32s'),
+  )
+  def test_pack_override_dtype(self, value, dtype, expected_payload):
+    tensor = tensor_utils.pack_tensor(value, dtype=dtype)
+    array = np.asarray(value, dtype)
+    self.assertEqual(expected_payload, tensor.WhichOneof('payload'))
+    packed_array = getattr(tensor, expected_payload).array
+    np.testing.assert_array_equal(array, packed_array)
+
   def test_pack_proto_arrays(self):
     array = np.array([
         struct_pb2.Value(string_value=message)
@@ -416,7 +430,7 @@ class DataTypeToNpTypeTests(absltest.TestCase):
 
   def test_unknown_type(self):
     with self.assertRaises(TypeError):
-      tensor_utils.data_type_to_np_type(30)
+      tensor_utils.data_type_to_np_type(30)  # pytype: disable=wrong-arg-types
 
 
 class NpTypeToDataTypeTests(absltest.TestCase):
